@@ -1,3 +1,9 @@
+/*
+ * SPDX-FileCopyrightText: 2019-2023 Mattia Basaglia <dev@dragon.best>
+ *
+ * SPDX-License-Identifier: GPL-3.0-or-later
+ */
+
 #pragma once
 
 #include <limits>
@@ -61,9 +67,42 @@ public:
         time_ *= multiplier;
     }
 
+    /**
+     * \brief Splits a keyframe into multiple segments
+     * \param other The keyframe following this
+     * \param splits Array of splits in [0, 1], indicating the fractions at which splits shall occur
+     * \pre \p other must be the same type of keyframe as \b this
+     * \returns An array of keyframes matching the splits,
+     *      this will include a copy of \p other, which might have been modified slightly.
+     *      This should be used as \p this for the next keyframe
+     */
+    std::vector<std::unique_ptr<KeyframeBase>> split(const KeyframeBase* other, std::vector<qreal> splits) const;
+
+    std::unique_ptr<KeyframeBase> clone() const
+    {
+        auto clone = do_clone();
+        clone->set_transition(transition_);
+        return clone;
+    }
+
 signals:
     void transition_changed(KeyframeTransition::Descriptive before, KeyframeTransition::Descriptive after);
 
+protected:
+    virtual std::unique_ptr<KeyframeBase> do_clone() const = 0;
+
+    class KeyframeSplitter
+    {
+    public:
+        virtual ~KeyframeSplitter() = default;
+        virtual void step(const QPointF& p) = 0;
+        virtual std::unique_ptr<KeyframeBase> left(const QPointF& p) const = 0;
+        virtual std::unique_ptr<KeyframeBase> right(const QPointF& p) const = 0;
+        virtual std::unique_ptr<KeyframeBase> last() const = 0;
+    };
+
+    virtual std::unique_ptr<KeyframeSplitter> splitter(const KeyframeBase* other) const = 0;
+
 private:
     FrameTime time_;
     KeyframeTransition transition_;
@@ -331,6 +370,47 @@ public:
         return math::lerp(value_, other.get(), this->transition().lerp_factor(t));
     }
 
+
+protected:
+    std::unique_ptr<KeyframeBase> do_clone() const override
+    {
+        return std::make_unique<Keyframe>(time(), value_);
+    }
+
+    class TypedKeyframeSplitter : public KeyframeSplitter
+    {
+    public:
+        TypedKeyframeSplitter(const Keyframe* a, const Keyframe* b) : a(a), b(b) {}
+
+        void step(const QPointF&) override {}
+
+        std::unique_ptr<KeyframeBase> left(const QPointF& p) const override
+        {
+            return std::make_unique<Keyframe>(
+                math::lerp(a->time(), b->time(), p.x()),
+                math::lerp(a->get(), b->get(), p.y())
+            );
+        }
+
+        std::unique_ptr<KeyframeBase> right(const QPointF& p) const override
+        {
+            return std::make_unique<Keyframe>(
+                math::lerp(a->time(), b->time(), p.x()),
+                math::lerp(a->get(), b->get(), p.y())
+            );
+        }
+
+        std::unique_ptr<KeyframeBase> last() const override { return b->clone(); }
+
+        const Keyframe* a;
+        const Keyframe* b;
+    };
+
+    virtual std::unique_ptr<KeyframeSplitter> splitter(const KeyframeBase* other) const override
+    {
+        return std::make_unique<TypedKeyframeSplitter>(this, static_cast<const Keyframe*>(other));
+    }
+
 private:
     Type value_;
 };
@@ -346,6 +426,11 @@ public:
     Keyframe(FrameTime time, const QPointF& value)
         : KeyframeBase(time), point_(value) {}
 
+
+    Keyframe(FrameTime time, const math::bezier::Point& value)
+        : KeyframeBase(time), point_(value), linear(point_is_linear(value))
+        {}
+
     void set(reference value)
     {
         point_.translate_to(value);
@@ -390,7 +475,7 @@ public:
     void set_point(const math::bezier::Point& point)
     {
         point_ = point;
-        linear = point_.tan_in == point.pos && point.tan_out == point.pos;
+        linear = point_is_linear(point);
     }
 
     const math::bezier::Point& point() const
@@ -410,7 +495,21 @@ public:
         return linear;
     }
 
+protected:
+    std::unique_ptr<KeyframeBase> do_clone() const override
+    {
+        return std::make_unique<Keyframe>(time(), point_);
+    }
+
+    class PointKeyframeSplitter;
+    std::unique_ptr<KeyframeSplitter> splitter(const KeyframeBase* other) const override;
+
 private:
+    static bool point_is_linear(const math::bezier::Point& point)
+    {
+        return point.tan_in == point.pos && point.tan_out == point.pos;
+    }
+
     math::bezier::Point point_;
     bool linear = true;
 };
@@ -843,8 +942,7 @@ protected:
         // Interpolate between two keyframes
         const keyframe_type* second = keyframe(index+1);
         double scaled_time = (time - first->time()) / (second->time() - first->time());
-        double lerp_factor = first->transition().lerp_factor(scaled_time);
-        return {nullptr, first->lerp(*second, lerp_factor)};
+        return {nullptr, first->lerp(*second, scaled_time)};
     }
 
     QVariant do_mid_transition_value(const KeyframeBase* kf_before, const KeyframeBase* kf_after, qreal ratio) const override
@@ -883,9 +981,9 @@ public:
 
     Q_INVOKABLE void split_segment(int index, qreal factor);
 
-    Q_INVOKABLE bool set_bezier(math::bezier::Bezier bezier);
+    Q_INVOKABLE bool set_bezier(glaxnimate::math::bezier::Bezier bezier);
 
-    Q_INVOKABLE math::bezier::Bezier bezier() const;
+    Q_INVOKABLE glaxnimate::math::bezier::Bezier bezier() const;
 
     void remove_points(const std::set<int>& indices);
 
@@ -899,6 +997,12 @@ public:
 
     void add_smooth_keyframe_undoable(FrameTime time, const QVariant& value) override;
 
+    /**
+     * \brief Gets the bezier derivative at the given time
+     * \returns The derivative point, if defined
+     */
+    std::optional<QPointF> derivative_at(FrameTime time) const;
+
 signals:
     /// Invoked on set_bezier()
     void  bezier_set(const math::bezier::Bezier& bezier);
